@@ -6,15 +6,15 @@ use warnings;
 
 =head1 NAME
 
-App::matrixpack - The great new App::matrixpack!
+App::matrixpack - Bundles multiple input lines with tab character into one repeatedly. Useful a little more than "column" command.  
 
 =head1 VERSION
 
-Version 0.00_13
+3ersion 0.00_14
 
 =cut
 
-our $VERSION = '0.0013';
+our $VERSION = '0.0014';
 
 
 =head1 SYNOPSIS
